---
canonical: https://grafana.com/docs/alloy/latest/reference/components/beyla/beyla.ebpf/
aliases:
  - ../beyla.ebpf/ # /docs/alloy/latest/reference/components/beyla.ebpf/
description: Learn about beyla.ebpf
labels:
  stage: general-availability
  products:
    - oss
title: beyla.ebpf
---

# `beyla.ebpf`

{{< admonition type="note" >}}
The `beyla.ebpf` component uses Grafana Beyla version {{< param "BEYLA_VERSION" >}}.
{{< /admonition >}}

The `beyla.ebpf` component is a wrapper for [Grafana Beyla][] which uses [eBPF][[eBPF website]] to automatically inspect application executables and the OS networking layer, and capture trace spans related to web transactions and Rate Errors Duration (RED) metrics for Linux HTTP/S and gRPC services.
You can configure the component to collect telemetry data from a specific port or executable path, and other criteria from Kubernetes metadata.
The component exposes metrics that can be collected by a Prometheus scrape component, and traces that can be forwarded to an OTel exporter component.

{{< admonition type="note" >}}
To run this component, {{< param "PRODUCT_NAME" >}} requires administrative privileges, or at least it needs to be granted the following capabilities: `BPF`, `SYS_PTRACE`, `NET_RAW` `CAP_CHECKPOINT_RESTORENET_RAW`, `DAC_READ_SEARCH`, and `PERFMON`.
The number of required capabilities depends on the specific use case.
Refer to the [Beyla capabilities](https://grafana.com/docs/beyla/latest/security/#list-of-capabilities-required-by-beyla) for more information.

In Kubernetes environments, the [AppArmor profile must be `Unconfined`](https://kubernetes.io/docs/tutorials/security/apparmor/#securing-a-pod) for the Deployment or DaemonSet running {{< param "PRODUCT_NAME" >}}.
{{< /admonition >}}

## Usage

```alloy
beyla.ebpf "<LABEL>" {

}
```

## Arguments

You can use the following arguments with `beyla.ebpf`:

| Name               | Type     | Description                                                    | Default      | Required |
| ------------------ | -------- | -------------------------------------------------------------- | ------------ | -------- |
| `debug`            | `bool`   | Enable debug mode for Beyla.                                   | `false`      | no       |
| `enforce_sys_caps` | `bool`   | Enforce system capabilities required for eBPF instrumentation. | `false`      | no       |
| `trace_printer`    | `string` | Format for printing trace information.                         | `"disabled"` | no       |


`debug` enables debug mode for Beyla. This mode logs BPF logs, network logs, trace representation logs, and other debug information.

When `enforce_sys_caps`  is set to true and the required system capabilities aren't present, Beyla aborts its startup and logs a list of the missing capabilities.

`trace_printer` is used to print the trace information in a specific format.
The following formats are supported:

* `disabled`: Disables trace printing.
* `counter`: Prints the trace information in a counter format.
* `text`: Prints the trace information in a text format.
* `json`: Prints the trace information in a JSON format.
* `json_indent`: Prints the trace information in a JSON format with indentation.

## Blocks

You can use the following blocks with `beyla.ebpf`:

| Block                                                                  | Description                                                                                        | Required |
| ---------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------- | -------- |
| [`output`][output]                                                     | Configures where to send received telemetry data.                                                  | yes      |
| [`attributes`][attributes]                                             | Configures the Beyla attributes for the component.                                                 | no       |
| `attributes` > [`kubernetes`][kubernetes attributes]                   | Configures decorating of the metrics and traces with Kubernetes metadata of the instrumented Pods. | no       |
| `attributes` > [`instance_id`][instance_id]                            | Configures instance ID settings.                                                                   | no       |
| `attributes` > [`select`][select]                                      | Configures which attributes to include or exclude for specific sections.                           | no       |
| [`discovery`][discovery]                                               | Configures the discovery for processes to instrument matching given criteria.                      | no       |
| `discovery` > [`exclude_services`][services]                           | Configures the services to exclude for the component.                                              | no       |
| `discovery` > `exclude_services` > [`kubernetes`][kubernetes services] | Configures the Kubernetes services to exclude for the component.                                   | no       |
| `discovery` > [`services`][services]                                   | Configures the services to discover for the component.                                             | no       |
| `discovery` > `services` > [`kubernetes`][kubernetes services]         | Configures the Kubernetes services to discover for the component.                                  | no       |
| [`ebpf`][ebpf]                                                         | Configures eBPF-specific settings.                                                                 | no       |
| [`filters`][filters]                                                   | Configures filtering of attributes.                                                                | no       |
| `filters` > [`application`][application filters]                       | Configures filtering of application attributes.                                                    | no       |
| `filters` > [`network`][network filters]                               | Configures filtering of network attributes.                                                        | no       |
| [`metrics`][metrics]                                                   | Configures which metrics Beyla exposes.                                                            | no       |
| `metrics` > [`network`][network metrics]                               | Configures network metrics options for Beyla.                                                      | no       |
| [`routes`][routes]                                                     | Configures the routes to match HTTP paths into user-provided HTTP routes.                          | no       |

The > symbol indicates deeper levels of nesting.
For example, `attributes` > `kubernetes` refers to a `kubernetes` block defined inside an `attributes` block.

[routes]: #routes
[attributes]: #attributes
[kubernetes attributes]: #kubernetes-attributes
[kubernetes services]: #kubernetes-services
[discovery]: #discovery
[services]: #services
[instance_id]: #instance_id
[select]: #select
[ebpf]: #ebpf
[filters]: #filters
[application filters]: #application
[metrics]: #metrics
[network metrics]: #network-metrics
[network filters]: #network-filters
[output]: #output

### `output`

<span class="badge docs-labels__stage docs-labels__item">Required</span>

The `output` block configures a set of components to forward the resulting telemetry data to.

The following arguments are supported:

| Name     | Type                     | Description                          | Default | Required |
| -------- | ------------------------ | ------------------------------------ | ------- | -------- |
| `traces` | `list(otelcol.Consumer)` | List of consumers to send traces to. | `[]`    | no       |

You must specify the `output` block, but all its arguments are optional.
By default, telemetry data is dropped.
Configure the `traces` argument to send traces data to other components.

### `attributes`

The `attributes` block configures how some attributes for metrics and traces are decorated.

It contains the following blocks:

#### `kubernetes` attributes

This `kubernetes` block configures the decorating of the metrics and traces with Kubernetes metadata from the instrumented Pods.

| Name                       | Type           | Description                                            | Default   | Required |
| -------------------------- | -------------- | ------------------------------------------------------ | --------- | -------- |
| `cluster_name`             | `string`       | The name of the Kubernetes cluster.                    | `""`      | no       |
| `disable_informers`        | `list(string)` | List of Kubernetes informers to disable.               | `[]`      | no       |
| `enable`                   | `string`       | Enable the Kubernetes metadata decoration.             | `false`   | no       |
| `informers_resync_period`  | `duration`     | Period for Kubernetes informers resynchronization.     | `"30m"`   | no       |
| `informers_sync_timeout`   | `duration`     | Timeout for Kubernetes informers synchronization.      | `"30s"`   | no       |
| `meta_restrict_local_node` | `bool`         | Restrict Kubernetes metadata collection to local node. | `false`   | no       |

If `cluster_name` isn't set, Beyla tries to detect the cluster name from the Kubernetes API.

If `enable` is set to `true`, Beyla decorates the metrics and traces with Kubernetes metadata.
The following labels are added:

* `k8s.daemonset.name`
* `k8s.deployment.name`
* `k8s.namespace.name`
* `k8s.node.name`
* `k8s.pod.name`
* `k8s.pod.start_time`
* `k8s.pod.uid`
* `k8s.replicaset.name`
* `k8s.statefulset.name`

If `enable` is set to `false`, the Kubernetes metadata decorator is disabled.

If `enable` is set to `autodetect`, Beyla tries to detect if it's running inside Kubernetes, and enables the metadata decoration if that's the case.

In `disable_informers`, you can specify the Kubernetes informers to disable. The accepted value is a list that might contain `node` and `service`.

#### `instance_id`

The `instance_id` block configures instance ID settings.

| Name                | Type     | Description                                             | Default | Required |
| ------------------- | -------- | ------------------------------------------------------- | ------- | -------- |
| `dns`               | `bool`   | Enable DNS resolution for hostname.                     | `true`  | no       |
| `override_hostname` | `string` | Override the hostname used for instance identification. | `""`    | no       |

#### `select`

The `select` block configures which attributes to include or exclude for specific metric/trace sections.

| Name      | Type           | Description                                            | Default | Required |
| --------- | -------------- | ------------------------------------------------------ | ------- | -------- |
| `attr`    | `string`       | The attribute name to select.                          | `[]`    | yes      |
| `exclude` | `list(string)` | List of attributes to exclude.                         | `[]`    | no       |
| `include` | `list(string)` | List of attributes to include. Use `*` to include all. | `[]`    | no       |

`include` is a list of attributes that need to be reported.
Each attribute can be an attribute name or a wildcard, for example, `k8s.dst.*` to include all the attributes starting with `k8s.dst`.

`exclude` is a list to of attribute names/wildcards containing the attributes to remove from the `include` list, or from the default attribute set.

The following example shows how you can include and exclude specific attributes:

```alloy
beyla.ebpf "default" {
attributes {
    select {
        attr = "sql_client_duration"
        include = ["*"]
        exclude = ["db_statement"]
    }
  }
}
```

Additionally, you can use `*` wildcards as metric names to add and exclude attributes for groups of metrics having the same name.
For example:

```alloy
beyla.ebpf "default" {
  attributes {
    select {
        attr = "http_*"
        include = ["*"]
        exclude = ["http_path", "http_route"]
    }
    select {
        attr = "http_client_*"
        // override http_* exclusion
        include = ["http_path"]
    }
  }
}
```

In the previous example, all the metrics with a name starting with `http_` or `http.` would include all the possible attributes but `http_path` and `http_route` or `http.path` and `http.route`.
The `http_client_*` section would override the base configuration, enabling the `http_path` attribute for the HTTP client metrics and `http_route` for the HTTP server metrics.

### `discovery`

The `discovery` block configures the discovery for processes to instrument matching given criteria.

| Name                                 | Type   | Description                                                        | Default | Required |
| ------------------------------------ | ------ | ------------------------------------------------------------------ | ------- | -------- |
| `exclude_otel_instrumented_services` | `bool` | Exclude services that are already instrumented with OpenTelemetry. | `true`  | no       |
| `skip_go_specific_tracers`           | `bool` | Skip Go-specific tracers during discovery.                         | `false` | no       |

It contains the following blocks:

#### `services`

In some scenarios, Beyla instruments a wide variety of services, such as a Kubernetes DaemonSet that instruments all the services in a node.
The `services` block allows you to filter the services to instrument based on their metadata. If you specify other selectors in the same services entry,
the instrumented processes need to match all the selector properties.

The same properties are available for both `services` and `exclude_services` blocks.
The `services` block configures the services to discover for the component.
The `exclude_services` block configures the services to exclude for the component.

| Name              | Type     | Description                                                                     | Default | Required |
| ----------------- | -------- | ------------------------------------------------------------------------------- | ------- | -------- |
| `name`            | `string` | The name of the service to match.                                               | `""`    | no       |
| `namespace`       | `string` | The namespace of the service to match.                                          | `""`    | no       |
| `open_ports`      | `string` | The port of the running service for Beyla automatically instrumented with eBPF. | `""`    | no       |
| `exe_path`        | `string` | The path of the running service for Beyla automatically instrumented with eBPF. | `""`    | no       |
| `containers_only` | `bool`   | Restrict the discovery to processes which are running inside a container.       | `false` | no       |

`exe_path` accepts a regular expression to be matched against the full executable command line, including the directory where the executable resides on the file system.

`name` defines a name for the matching instrumented service.
It's used to populate the `service.name` OTel property or the `service_name` Prometheus property in the exported metrics/traces.

`open_port` accepts a comma-separated list of ports (for example, `80,443`), and port ranges (for example, `8000-8999`).
If the executable matches only one of the ports in the list, it's considered to match the selection criteria.

#### `default_exclude_services`

The `default_exclude_services` is special services block that disables instrumentation of Grafana Alloy. The default value for `exe_path` is `"(?:^|\/)(beyla$|alloy$|otelcol[^\/]*$)"`.
Set to empty to allow Alloy to instrument itself as well as these other components.

#### `kubernetes` services

This `kubernetes` block filters the services to instrument based on their Kubernetes metadata. If you specify other selectors in the same services entry,
the instrumented processes need to match all the selector properties.

| Name               | Type          | Description                                                                                                        | Default | Required |
| ------------------ | ------------- | ------------------------------------------------------------------------------------------------------------------ | ------- | -------- |
| `daemonset_name`   | `string`      | Regular expression of Kubernetes DaemonSets to match.                                                              | `""`    | no       |
| `deployment_name`  | `string`      | Regular expression of Kubernetes Deployments to match.                                                             | `""`    | no       |
| `namespace`        | `string`      | Regular expression of Kubernetes Namespaces to match.                                                              | `""`    | no       |
| `owner_name`       | `string`      | Regular expression of Kubernetes owners of running Pods to match.                                                  | `""`    | no       |
| `pod_labels`       | `map(string)` | Key-value pairs of labels with keys matching Kubernetes Pods with the provided value as regular expression.        | `{}`    | no       |
| `pod_annotations`  | `map(string)` | Key-value pairs of labels with keys matching Kubernetes annotations with the provided value as regular expression. | `{}`    | no       |
| `pod_name`         | `string`      | Regular expression of Kubernetes Pods to match.                                                                    | `""`    | no       |
| `replicaset_name`  | `string`      | Regular expression of Kubernetes ReplicaSets to match.                                                             | `""`    | no       |
| `statefulset_name` | `string`      | Regular expression of Kubernetes StatefulSets to match.                                                            | `""`    | no       |

Example:

``` alloy
beyla.ebpf "default" {
  discovery {
    // Instrument all services with 8080 open port
    services {
      open_ports = "8080"
    }
    // Instrument all services from the default namespace
    services {
      kubernetes {
        namespace = "default"
      }
    }
    // Exclude all services from the kube-system namespace
    exclude_services {
      kubernetes {
        namespace = "kube-system"
      }
    }
  }
}
```

### `ebpf`

The `ebpf` block configures eBPF-specific settings.

| Name                          | Type          | Description                                                                    | Default      | Required |
| ----------------------------- | ------------- | ------------------------------------------------------------------------------ | ------------ | -------- |
| `wakeup_len`                  | `int`         | Number of messages to accumulate before wakeup request.                        | `""`         | no       |
| `track_request_headers`       | `bool`        | Enable tracking of request headers for Traceparent fields.                     | `false`      | no       |
| `http_request_timeout`        | `duration`    | Timeout for HTTP requests.                                                     | `"30s"`      | no       |
| `context_propagation`         | `string`      | Enables injecting of the Traceparent header value for outgoing HTTP requests.  | `"disabled"` | no       |
| `high_request_volume`         | `bool`        | Optimize for immediate request information when response is seen.              | `false`      | no       |
| `heuristic_sql_detect`        | `bool`        | Enable heuristic-based detection of SQL requests.                              | `false`      | no       |


#### `context_propagation`

`context_propagation` allows Beyla to propagate any incoming context to downstream services. 
This context propagation support works for any programming language.

For TLS encrypted HTTP requests (HTTPS), the Traceparent header value is encoded at TCP/IP packet level, 
and requires that Beyla is present on both sides of the communication.

The TCP/IP packet level encoding uses Linux Traffic Control (TC). 
eBPF programs that also use TC need to chain correctly with Beyla. 
For more information about chaining programs, refer to the [Cilium compatibility][cilium] documentation.

You can disable the TCP/IP level encoding and TC programs by setting `context_propagation` to `"headers"`. 
This context propagation support is fully compatible with any OpenTelemetry distributed tracing library.

`context_propagation` can be set to either one of the following values:

* `all`: Enable both HTTP and IP options context propagation.
* `headers`: Enable context propagation via the HTTP headers only.
* `ip`: Enable context propagation via the IP options field only.
* `disabled`: Disable trace context propagation.

[cilium]: https://grafana.com/docs/beyla/latest/cilium-compatibility/

### `filters`

The `filters` block allows you to filter both application and network metrics by attribute values.

For a list of metrics under the application and network family, as well as their attributes, refer to the [Beyla exported metrics][].

It contains the following blocks:

#### `application`

The `application` block configures filtering of application attributes.

| Name        | Type     | Description                              | Required |
| ----------- | -------- | -----------------------------------------| -------- |
| `attr`      | `string` | The name of the attribute to match.      | yes      |
| `match`     | `string` | String to match attribute values.        | no       |
| `not_match` | `string` | String to exclude matching values.       | no       |

Both properties accept a
[glob-like](https://github.com/gobwas/glob) string (it can be a full value or include
wildcards).

#### `network` filters

The `network` block configures filtering of network attributes.

| Name        | Type     | Description                              | Required |
| ----------- | -------- | ---------------------------------------- | -------- |
| `attr`      | `string` | The name of the attribute to match.      | yes      |
| `match`     | `string` | String to match attribute values.        | no       |
| `not_match` | `string` | String to exclude matching values.       | no       |

Both properties accept a
[glob-like](https://github.com/gobwas/glob) string (it can be a full value or include
wildcards).

Example:

```alloy
beyla.ebpf "default" {
  filters {
    application {
      attr = "url.path"
      match = "/user/*"
    }
    network {
      attr = "k8s.src.owner.name"
      match = "*"
    }
  }
}
```

### `metrics`

The `metrics` block configures which metrics Beyla collects.

| Name                                  | Type           | Description                                                | Default           | Required |
| ------------------------------------- | -------------- | ---------------------------------------------------------- | ----------------- | -------- |
| `allow_service_graph_self_references` | `bool`         | Allow service graph metrics to reference the same service. | `false`           | no       |
| `features`                            | `list(string)` | List of features to enable for the metrics.                | `["application"]` | no       |
| `instrumentations`                    | `list(string)` | List of instrumentations to enable for the metrics.        | `["*"]`           | no       |

`features` is a list of features to enable for the metrics. The following features are available:

* `application` exports application-level metrics.
* `application_process` exports metrics about the processes that run the instrumented application.
* `application_service_graph` exports application-level service graph metrics.
* `application_span` exports application-level metrics in traces span metrics format.
* `network` exports network-level metrics.

`instrumentations` is a list of instrumentations to enable for the metrics. The following instrumentations are available:

* `*` enables all `instrumentations`. If `*` is present in the list, the other values are ignored.
* `grpc` enables the collection of gRPC application metrics.
* `http` enables the collection of HTTP/HTTPS/HTTP2 application metrics.
* `kafka` enables the collection of Kafka client/server message queue metrics.
* `redis` enables the collection of Redis client/server database metrics.
* `sql` enables the collection of SQL database client call metrics.

#### `network` metrics

The `network` block configures network metrics options for Beyla. You must append `network` to the `features` list in the `metrics` block to enable network metrics.

| Name                   | Type           | Description                                                           | Default           | Required |
| ---------------------- | -------------- | --------------------------------------------------------------------- | ----------------- | -------- |
| `agent_ip_iface`       | `string`       | Network interface to get agent IP from.                               | `"external"`      | no       |
| `agent_ip_type`        | `string`       | Type of IP address to use.                                            | `"any"`           | no       |
| `agent_ip`             | `string`       | Allows overriding the reported `beyla.ip` attribute on each metric.   | `""`              | no       |
| `cache_active_timeout` | `duration`     | Timeout for active flow cache entries.                                | `"5s"`            | no       |
| `cache_max_flows`      | `int`          | Maximum number of flows to cache.                                     | `5000`            | no       |
| `cidrs`                | `list(string)` | List of CIDR ranges to monitor.                                       | `[]`              | no       |
| `direction`            | `string`       | Direction of traffic to monitor.                                      | `"both"`          | no       |
| `exclude_interfaces`   | `list(string)` | List of network interfaces to exclude from monitoring.                | `["lo"]`          | no       |
| `exclude_protocols`    | `list(string)` | List of protocols to exclude from monitoring.                         | `[]`              | no       |
| `interfaces`           | `list(string)` | List of network interfaces to monitor.                                | `[]`              | no       |
| `protocols`            | `list(string)` | List of protocols to monitor.                                         | `[]`              | no       |
| `sampling`             | `int`          | Sampling rate for network metrics.                                    | `0` (disabled)    | no       |
| `source`               | `string`       | Linux Kernel feature used to source the network events Beyla reports. | `"socket_filter"` | no       |

You can set `source` to `socket_filter` or `tc`.

* `socket_filter` is used as an event source.
   Beyla installs an eBPF Linux socket filter to capture the network events.
* `tc` is used as a kernel module.
   Beyla uses the Linux Traffic Control ingress and egress filters to capture the network events, in a direct action mode.

You can set `agent_ip_iface` to `external` (default), `local`, or `name:<interface name>`, for example `name:eth0`.

You can set `agent_ip_type` to `ipv4`, `ipv6`, or `any` (default).

`protocols` and `exclude_protocols` are defined in the Linux enumeration of [Standard well-defined IP protocols](https://elixir.bootlin.com/linux/v6.8.7/source/include/uapi/linux/in.h#L28), and can be:

{{< column-list >}}

* `AH`
* `BEETPH`
* `COMP`
* `DCCP`
* `EGP`
* `ENCAP`
* `ESP`
* `ETHERNET`
* `GRE`
* `ICMP`
* `IDP`
* `IGMP`
* `IP`
* `IPIP`
* `IPV6`
* `L2TP`
* `MPLS`
* `MTP`
* `PIM`
* `PUP`
* `RAW`
* `RSVP`
* `SCTP`
* `TCP`
* `TP`
* `UDP`
* `UDPLITE`

{{< /column-list >}}

You can set `direction` to `ingress`, `egress`, or `both` (default).

`sampling` defines the rate at which packets should be sampled and sent to the target collector. For example, if you set it to 100, one out of 100 packets, on average, are sent to the target collector.

### `routes`

The `routes` block configures the routes to match HTTP paths into user-provided HTTP routes.

| Name              | Type           | Description                                                                              | Default       | Required |
| ----------------- | -------------- | ---------------------------------------------------------------------------------------- | ------------- | -------- |
| `ignore_mode`     | `string`       | The mode to use when ignoring patterns.                                                  | `""`          | no       |
| `ignore_patterns` | `list(string)` | List of provided URL path patterns to ignore from `http.route` trace/metric property.    | `[]`          | no       |
| `patterns`        | `list(string)` | List of provided URL path patterns to set the `http.route` trace/metric property.        | `[]`          | no       |
| `unmatched`       | `string`       | Specifies what to do when a trace HTTP path doesn't match any of the `patterns` entries. | `"heuristic"` | no       |
| `wildcard_char`   | `string`       | Character to use as wildcard in patterns.                                                | `"*"`         | no       |

`ignore_mode` properties are:

* `all` discards metrics and traces matching the `ignored_patterns`.
* `metrics` discards only the metrics that match the `ignored_patterns`. No trace events are ignored.
* `traces` discards only the traces that match the `ignored_patterns`. No metric events are ignored.

`patterns` and `ignore_patterns` are a list of patterns which a URL path with specific tags which allow for grouping path segments (or ignored them).
The matcher tags can be in the `:name` or `{name}` format.

`unmatched` properties are:

* `heuristic` automatically derives the `http.route` field property from the path value based on the following rules:
  * Any path components that have numbers or characters outside of the ASCII alphabet (or `-` and _), are replaced by an asterisk `*`.
  * Any alphabetical components that don't look like words are replaced by an asterisk `*`.
* `path` copies the `http.route` field property to the path value.
  {{< admonition type="caution" >}}
  This property could lead to a cardinality explosion on the ingester side.
  {{< /admonition >}}
* `unset` leaves the `http.route` property as unset.
* `wildcard` sets the `http.route` field property to a generic asterisk-based `/**` value.

## Exported fields

The following fields are exported and can be referenced by other components.

| Name      | Type                | Description                                                                         |
| --------- | ------------------- | ----------------------------------------------------------------------------------- |
| `targets` | `list(map(string))` | The targets that can be used to collect metrics of instrumented services with eBPF. |

For example, the `targets` can either be passed to a `discovery.relabel` component to rewrite the targets' label sets or to a `prometheus.scrape` component that collects the exposed metrics.

The exported targets use the configured [in-memory traffic][] address specified by the [run command][].

## Component health

`beyla.ebpf` is only reported as unhealthy if given an invalid configuration.

## Debug information

`beyla.ebpf` doesn't expose any component-specific debug information.

## Examples

The following examples show you how to collect metrics and traces from `beyla.ebpf`.

### Metrics

This example uses a [`prometheus.scrape` component][scrape] to collect metrics from `beyla.ebpf` of the specified port:

```alloy
beyla.ebpf "default" {
  discovery {
    services {
      open_ports = <OPEN_PORT>
    }
  }

  metrics {
    features = [
     "application", 
    ]
  }
}

prometheus.scrape "beyla" {
  targets = beyla.ebpf.default.targets
  honor_labels = true // required to keep job and instance labels
  forward_to = [prometheus.remote_write.demo.receiver]
}

prometheus.remote_write "demo" {
  endpoint {
    url = <PROMETHEUS_REMOTE_WRITE_URL>

    basic_auth {
      username = <USERNAME>
      password = <PASSWORD>
    }
  }
}
```

#### Kubernetes

This example gets metrics from `beyla.ebpf` for the specified namespace and Pods running in a Kubernetes cluster:

```alloy
beyla.ebpf "default" {
  attributes {
    kubernetes {
     enable = "true"
    }
  }
  discovery {
    services {
     kubernetes {
      namespace = "<NAMESPACE>"
      pod_name = "<POD_NAME>"
     }
    }
  }
  metrics {
    features = [
     "application", 
    ]
  }
}

prometheus.scrape "beyla" {
  targets = beyla.ebpf.default.targets
  honor_labels = true // required to keep job and instance labels
  forward_to = [prometheus.remote_write.demo.receiver]
}

prometheus.remote_write "demo" {
  endpoint {
    url = <PROMETHEUS_REMOTE_WRITE_URL>

    basic_auth {
      username = <USERNAME>
      password = <PASSWORD>
    }
  }
}
```

Replace the following:

* _`<OPEN_PORT>`_: The port of the running service for Beyla automatically instrumented with eBPF.
* _`<NAMESPACE>`_: The namespaces of the applications running in a Kubernetes cluster.
* _`<POD_NAME>`_: The name of the Pods running in a Kubernetes cluster.
* _`<PROMETHEUS_REMOTE_WRITE_URL>`_: The URL of the Prometheus remote_write-compatible server to send metrics to.
* _`<USERNAME>`_: The username to use for authentication to the `remote_write` API.
* _`<PASSWORD>`_: The password to use for authentication to the `remote_write` API.

### Traces

This example gets traces from `beyla.ebpf` and forwards them to `otlp`:

```alloy
beyla.ebpf "default" {
  discovery {
    services {
      open_ports = <OPEN_PORT>
    }
  }
  output {
    traces = [otelcol.processor.batch.default.input]
  }
}

otelcol.processor.batch "default" {
  output {
    traces  = [otelcol.exporter.otlp.default.input]
  }
}

otelcol.exporter.otlp "default" {
  client {
    endpoint = sys.env("<OTLP_ENDPOINT>")
  }
}
```

Replace the following:

* _`<OPEN_PORT>`_: The port of the running service for Beyla automatically instrumented with eBPF.
* _`<OTLP_ENDPOINT>`_: The endpoint of the OpenTelemetry Collector to send traces to.

[Grafana Beyla]: https://github.com/grafana/beyla
[eBPF website]: https://ebpf.io/
[in-memory traffic]: ../../../../get-started/component_controller/#in-memory-traffic
[run command]: ../../../cli/run/
[scrape]: ../../prometheus/prometheus.scrape/
[Distributed traces with Beyla]: /docs/beyla/latest/distributed-traces/
[Beyla exported metrics]: /docs/beyla/latest/metrics/

<!-- START GENERATED COMPATIBLE COMPONENTS -->

## Compatible components

`beyla.ebpf` can accept arguments from the following components:

- Components that export [OpenTelemetry `otelcol.Consumer`](../../../compatibility/#opentelemetry-otelcolconsumer-exporters)

`beyla.ebpf` has exports that can be consumed by the following components:

- Components that consume [Targets](../../../compatibility/#targets-consumers)

{{< admonition type="note" >}}
Connecting some components may not be sensible or components may require further configuration to make the connection work correctly.
Refer to the linked documentation for more details.
{{< /admonition >}}

<!-- END GENERATED COMPATIBLE COMPONENTS -->
